@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminRoleGroup;
@@ -37,7 +37,7 @@ sub Run {
     if ( $Self->{Subaction} eq 'Role' ) {
 
         # get user data
-        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my $ID       = $ParamObject->GetParam( Param => 'ID' );
         my %RoleData = $GroupObject->RoleGet( ID => $ID );
 
         # get group data
@@ -70,7 +70,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Group' ) {
 
         # get group data
-        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my $ID        = $ParamObject->GetParam( Param => 'ID' );
         my %GroupData = $GroupObject->GroupGet( ID => $ID );
 
         # get user list
@@ -138,7 +138,19 @@ sub Run {
                 UserID     => $Self->{UserID},
             );
         }
-        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+
+        # if the user would like to continue editing the role-group relation just redirect to the edit screen
+        # otherwise return to relations overview
+        if (
+            defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
+            && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
+            )
+        {
+            return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=Group;ID=$ID" );
+        }
+        else {
+            return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+        }
     }
 
     # ------------------------------------------------------------ #
@@ -180,7 +192,19 @@ sub Run {
                 UserID     => $Self->{UserID},
             );
         }
-        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+
+        # if the user would like to continue editing the group-role relation just redirect to the edit screen
+        # otherwise return to relations overview
+        if (
+            defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
+            && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
+            )
+        {
+            return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=Role;ID=$ID" );
+        }
+        else {
+            return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
+        }
     }
 
     # ------------------------------------------------------------ #
@@ -203,6 +227,17 @@ sub _Change {
     my $Type   = $Param{Type} || 'Role';
     my $NeType = $Type eq 'Group' ? 'Role' : 'Group';
 
+    $Param{BreadcrumbTitle} = $LayoutObject->{LanguageObject}->Translate("Change Group Relations for Role");
+
+    if ( $Type eq 'Group' ) {
+        $Param{BreadcrumbTitle} = $LayoutObject->{LanguageObject}->Translate("Change Role Relations for Group");
+    }
+
+    $LayoutObject->Block(
+        Name => 'Overview',
+        Data => \%Param,
+    );
+
     $LayoutObject->Block(
         Name => 'Change',
         Data => {
@@ -211,11 +246,10 @@ sub _Change {
             NeType     => $NeType,
         },
     );
+
     $LayoutObject->Block( Name => 'ActionList' );
     $LayoutObject->Block( Name => 'ActionOverview' );
 
-    $LayoutObject->Block( Name => "ChangeHeader$NeType" );
-
     # check if there are groups/roles
     if ( !%Data ) {
         $LayoutObject->Block(
@@ -226,6 +260,8 @@ sub _Change {
         );
     }
 
+    my @Permissions;
+
     TYPE:
     for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
         next TYPE if !$Type;
@@ -238,8 +274,16 @@ sub _Change {
                 Type => $Type,
             },
         );
+
+        push @Permissions, $Type;
     }
 
+    # set permissions
+    $LayoutObject->AddJSData(
+        Key   => 'RelationItems',
+        Value => \@Permissions,
+    );
+
     for my $ID ( sort { uc( $Data{$a} ) cmp uc( $Data{$b} ) } keys %Data ) {
 
         # set output class
@@ -289,6 +333,11 @@ sub _Overview {
         Data => {},
     );
 
+    $LayoutObject->Block(
+        Name => 'OverviewAction',
+        Data => {},
+    );
+
     # get user list
     my %RoleData = $GroupObject->RoleList( Valid => 1 );
 
