@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -344,7 +344,7 @@ sub Run {
         $Hash =~ s{(.+)\.\d}{$1}xms;
 
         my $Certificate = $SMIMEObject->CertificateGet( Filename => $Filename );
-        my %Attributes = $SMIMEObject->CertificateAttributes( Certificate => $Certificate );
+        my %Attributes  = $SMIMEObject->CertificateAttributes( Certificate => $Certificate );
         return $LayoutObject->Attachment(
             ContentType => 'text/plain',
             Content     => $Attributes{Fingerprint},
@@ -381,10 +381,11 @@ sub Run {
         else {
             $Download = $SMIMEObject->CertificateGet( Filename => $Filename );
         }
+
         return $LayoutObject->Attachment(
             ContentType => 'text/plain',
             Content     => $Download,
-            Filename    => "$Hash.pem",
+            Filename    => $Hash . '-' . $Type . '.pem',
             Type        => 'attachment',
         );
     }
@@ -396,7 +397,7 @@ sub Run {
 
         # look for needed parameters
         my $CertFingerprint = $ParamObject->GetParam( Param => 'Fingerprint' ) || '';
-        my $Output = $Self->_SignerCertificateOverview( CertFingerprint => $CertFingerprint );
+        my $Output          = $Self->_SignerCertificateOverview( CertFingerprint => $CertFingerprint );
 
         return $Output;
     }
@@ -656,6 +657,11 @@ sub _Overview {
                 $Attributes->{Type}    = 'Invalid';
                 $Attributes->{Subject} = "The file: '$Attributes->{Filename}' is invalid";
             }
+
+            if ( defined $Attributes->{EndDate} && $SMIMEObject->KeyExpiredCheck( EndDate => $Attributes->{EndDate} ) )
+            {
+                $Attributes->{Expired} = 1;
+            }
             $LayoutObject->Block(
                 Name => 'Row',
                 Data => $Attributes,
