@@ -220,11 +220,12 @@ sub _SupportDataCollectorView {
                     Data => $Entry,
                 );
 
-                if ( $Entry->{Message} ) {
+                if ( $Entry->{Message} || $Entry->{MessageFormatted} ) {
                     $LayoutObject->Block(
                         Name => 'SupportDataSubEntryMessage',
                         Data => {
-                            Message => $Entry->{Message},
+                            Message          => $Entry->{Message},
+                            MessageFormatted => $Entry->{MessageFormatted},
                         },
                     );
                 }
@@ -253,11 +254,15 @@ sub _SupportDataCollectorView {
     {
         $Param{SenderAddress} = $ConfigObject->Get('AdminEmail');
     }
-    $Param{SenderName} = $User{UserFirstname} . ' ' . $User{UserLastname};
+    $Param{SenderName} = $User{UserFullname};
 
     # verify if the email is valid, set it to empty string if not, this will be checked on client
     #    side
-    if ( !$Kernel::OM->Get('Kernel::System::CheckItem')->CheckEmail( Address => $Param{SenderAddress} ) ) {
+    if (
+        $Param{SenderAddress} &&
+        !$Kernel::OM->Get('Kernel::System::CheckItem')->CheckEmail( Address => $Param{SenderAddress} )
+        )
+    {
         $Param{SenderAddress} = '';
     }
 
@@ -493,7 +498,7 @@ sub _SendSupportBundle {
                 $SenderAddress = $ConfigObject->Get('AdminEmail');
             }
 
-            my $SenderName = $User{UserFirstname} . ' ' . $User{UserLastname};
+            my $SenderName = $User{UserFullname};
 
             my $Body;
 
@@ -510,7 +515,7 @@ sub _SendSupportBundle {
                 $Body .= "Not registered\n";
             }
 
-            my ( $HeadRef, $BodyRef ) = $Kernel::OM->Get('Kernel::System::Email')->Send(
+            my $Result = $Kernel::OM->Get('Kernel::System::Email')->Send(
                 From          => $SenderAddress,
                 To            => 'SupportBundle@otrs.com',
                 Subject       => 'Support::Bundle::Email',
@@ -530,7 +535,7 @@ sub _SendSupportBundle {
                 ],
             );
 
-            if ( $HeadRef && $BodyRef ) {
+            if ( $Result->{Success} ) {
                 $Success = 1;
             }
         }
@@ -561,4 +566,5 @@ sub _SendSupportBundle {
         NoCache     => 1,
     );
 }
+
 1;
