@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,6 +20,7 @@ use Unicode::Normalize;
 use List::Util qw();
 use Fcntl qw(:flock);
 use Encode;
+use Math::Random::Secure qw();
 
 use Kernel::System::VariableCheck qw(IsStringWithData);
 
@@ -224,24 +225,28 @@ sub FilenameCleanUp {
         # separate filename and extension
         my $FileName = $Param{Filename};
         my $FileExt  = '';
-        if ( $Param{Filename} =~ /(.*)\.+(.{1,10})$/ ) {
+        if ( $Param{Filename} =~ /(.*)\.+([^.]+)$/ ) {
             $FileName = $1;
             $FileExt  = '.' . $2;
         }
 
         if ( length $FileName ) {
-            my $ModifiedName;
+            my $ModifiedName = $FileName . $FileExt;
 
-            # remove character by character starting from the end of the filename string
-            # untill we get acceptable 220 byte long filename size including extension
-            CHOPSTRING:
-            while (1) {
+            while ( length encode( 'UTF-8', $ModifiedName ) > 220 ) {
+
+                # Remove character by character starting from the end of the filename string
+                #   until we get acceptable 220 byte long filename size including extension.
+                if ( length $FileName > 1 ) {
+                    chop $FileName;
+                }
+
+                # If we reached minimum filename length, remove characters from the end of the extension string.
+                else {
+                    chop $FileExt;
+                }
 
                 $ModifiedName = $FileName . $FileExt;
-
-                last CHOPSTRING if ( length encode( 'UTF-8', $ModifiedName ) < 220 );
-                chop $FileName;
-
             }
             $Param{Filename} = $ModifiedName;
         }
@@ -265,25 +270,30 @@ sub FilenameCleanUp {
         # separate filename and extension
         my $FileName = $Param{Filename};
         my $FileExt  = '';
-        if ( $Param{Filename} =~ /(.*)\.+(.{1,10})$/ ) {
+        if ( $Param{Filename} =~ /(.*)\.+([^.]+)$/ ) {
             $FileName = $1;
             $FileExt  = '.' . $2;
         }
 
         if ( length $FileName ) {
-            my $ModifiedName;
+            my $ModifiedName = $FileName . $FileExt;
 
-            # remove character by character starting from the end of the filename string
-            # untill we get acceptable 220 byte long filename size including extension
-            CHOPSTRING:
-            while (1) {
+            while ( length encode( 'UTF-8', $ModifiedName ) > 220 ) {
+
+                # Remove character by character starting from the end of the filename string
+                #   until we get acceptable 220 byte long filename size including extension.
+                if ( length $FileName > 1 ) {
+                    chop $FileName;
+                }
+
+                # If we reached minimum filename length, remove characters from the end of the extension string.
+                else {
+                    chop $FileExt;
+                }
 
                 $ModifiedName = $FileName . $FileExt;
-
-                last CHOPSTRING if ( length encode( 'UTF-8', $ModifiedName ) < 220 );
-                chop $FileName;
-
             }
+
             $Param{Filename} = $ModifiedName;
         }
     }
@@ -1055,7 +1065,7 @@ sub GenerateRandomString {
 
     for ( 1 .. $Length ) {
 
-        my $Key = int rand $DictionaryLength;
+        my $Key = int Math::Random::Secure::rand $DictionaryLength;
 
         $String .= $DictionaryChars[$Key];
     }
